:notoc:

======
Coiled
======

👋 Welcome to Coiled!

`Coiled <https://coiled.io/>`_ helps you easily create and manage `Dask <https://dask.org/>`_ deployments
to natively scale Python. We are currently in beta and welcoming early users. If you would like to join the beta, please
`sign up <https://coiled.typeform.com/to/mu6Inr4S>`_.

.. panels::
   :body: text-center
   :header: text-center h5 bg-white
   :footer: border-0 bg-white

   Coiled beta :opticon:`rocket,size=24`
   ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

   Want to try Coiled? Sign up for our beta!

   +++

   .. link-button:: https://coiled.typeform.com/to/mu6Inr4S
      :type: url
      :text: Sign up for the beta
      :classes: btn-outline-primary btn-block stretched-link

   ---

   Documentation :opticon:`info,size=24`
   ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

   Already signed up for the beta? Check out our documentation to get started with Coiled.

   +++

   .. link-button:: user_guide/index
      :type: ref
      :text: Go to the docs
      :classes: btn-outline-primary btn-block stretched-link


.. toctree::
   :maxdepth: 1
   :hidden:

   user_guide/index
